==> haskell-sourcemap-0.1.7-185-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sourcemap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sourcemap
version:              0.1.7
visibility:           public
id:                   sourcemap-0.1.7-FcweNOyEySdFgdPUieQ04k
key:                  sourcemap-0.1.7-FcweNOyEySdFgdPUieQ04k
license:              BSD-3-Clause
copyright:            2012 Chris Done
maintainer:           Jens Petersen <juhpetersen@gmail.com>
author:               Chris Done
stability:            alpha
synopsis:
    Implementation of source maps as proposed by Google and Mozilla.

description:
    Implementation of source maps, revision 3, proposed by Google and Mozilla here
    <https://wiki.mozilla.org/DevTools/Features/SourceMap> and here
    <https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit>

category:             Development
abi:                  f019526c4aee48b5af4a00616883ea7e
exposed:              True
exposed-modules:      SourceMap SourceMap.Types
hidden-modules:       VLQ
import-dirs:          /usr/lib/ghc-9.4.8/site-local/sourcemap-0.1.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sourcemap-0.1.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sourcemap-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sourcemap
hs-libraries:         HSsourcemap-0.1.7-FcweNOyEySdFgdPUieQ04k
depends:
    aeson-2.1.2.1-8pX4IwvbwpcwXiIiReOQk
    attoparsec-0.14.4-DGiM2cMH1LKFsy4siuUEV5 base-4.17.2.1
    bytestring-0.11.5.3 process-1.6.18.0 text-2.0.2
    unordered-containers-0.2.20-8U9CBLajvKUXcrLJVqNaj
    utf8-string-1.0.2-7x3IoasPx5wHP6oJo1JvJP

haddock-interfaces:   /usr/share/doc/haskell-sourcemap/html/sourcemap.haddock
haddock-html:         /usr/share/doc/haskell-sourcemap/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sourcemap-0.1.7-186-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sourcemap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sourcemap
version:              0.1.7
visibility:           public
id:                   sourcemap-0.1.7-ICQjWDZF4ibAjCLYIcjXAB
key:                  sourcemap-0.1.7-ICQjWDZF4ibAjCLYIcjXAB
license:              BSD-3-Clause
copyright:            2012 Chris Done
maintainer:           Jens Petersen <juhpetersen@gmail.com>
author:               Chris Done
stability:            alpha
synopsis:
    Implementation of source maps as proposed by Google and Mozilla.

description:
    Implementation of source maps, revision 3, proposed by Google and Mozilla here
    <https://wiki.mozilla.org/DevTools/Features/SourceMap> and here
    <https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit>

category:             Development
abi:                  122cbd0e7ac3642e694a4966c6e9f32a
exposed:              True
exposed-modules:      SourceMap SourceMap.Types
hidden-modules:       VLQ
import-dirs:          /usr/lib/ghc-9.4.8/site-local/sourcemap-0.1.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sourcemap-0.1.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sourcemap-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sourcemap
hs-libraries:         HSsourcemap-0.1.7-ICQjWDZF4ibAjCLYIcjXAB
depends:
    aeson-2.1.2.1-HgTvGelKFeMCs4MoB4HQQ3
    attoparsec-0.14.4-GPSHKdrOxNAHtLNPx9PvVS base-4.17.2.1
    bytestring-0.11.5.3 process-1.6.18.0 text-2.0.2
    unordered-containers-0.2.20-6lPJVAOvNaZ2RxvZwsH66g
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:   /usr/share/doc/haskell-sourcemap/html/sourcemap.haddock
haddock-html:         /usr/share/doc/haskell-sourcemap/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
